MethodChannelBleController class

An implementation of BleControllerPlatform that uses method channels.

Inheritance

Properties

bleAdapterStateEventChannel → EventChannel
final
bondingStateEventChannel → EventChannel
final
connectionStateEventChannel → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
notifyEventChannel → EventChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanEventChannel → EventChannel
final

Methods

connect(String address) → Future<bool?>
override
getBleAdapterStateStream() → Stream
override
getBleAdapterStateStream2() → Stream<BleAdapterState?>
override
getBondingStateStream() → Stream
override
getConnectionStateStream() → Stream
override
getNotifyStream() → Stream
override
getPlatformVersion() → Future<String?>
override
getScanStream() → Stream
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(bool? state) → Future<bool?>
override
sendData(String data) → Future<String>
override
setCharacteristicNotifyUUID(String charNotifyUUID) → Future<bool?>
override
setCharacteristicUUID(String charUUID) → Future<bool?>
override
setDescriptionUUID(String desUUID) → Future<bool?>
override
setServiceUUID(String svcUUID) → Future<bool?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited