BleControllerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BleControllerPlatform
Implementers

Constructors

BleControllerPlatform()
Constructs a BleControllerPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String address) → Future<bool?>
getBleAdapterStateStream() → Stream
getBleAdapterStateStream2() → Stream<BleAdapterState?>
getBondingStateStream() → Stream
getConnectionStateStream() → Stream
getNotifyStream() → Stream
getPlatformVersion() → Future<String?>
getScanStream() → Stream
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(bool? state) → Future<bool?>
sendData(String data) → Future<String?>
setCharacteristicNotifyUUID(String charNotifyUUID) → Future<bool?>
setCharacteristicUUID(String charUUID) → Future<bool?>
setDescriptionUUID(String desUUID) → Future<bool?>
setServiceUUID(String svcUUID) → Future<bool?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ BleControllerPlatform
The default instance of BleControllerPlatform to use.
getter/setter pair